<?php
function jeans_widgets_init() {  
	register_sidebar(array(
		'name' => __( 'sidebar', 'jeans' ),
		'before_widget' => '<li>', 
		'after_widget' => '</li>',
		'before_title' => '<h2>', 
		'after_title' => '</h2>' 
 
	));

}
	
	
function jeans_theme_init(){
	load_theme_textdomain('jeans', get_template_directory() . '/language');
}

add_action( 'widgets_init', 'jeans_widgets_init');

 
if(!isset($content_width)){
    $content_width = 676;
}



function jeans_setup() {

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );
	
	add_theme_support( 'post-formats', array( 'aside', 'link', 'gallery', 'status', 'quote', 'image' ) );

	// Make theme available for translation
	// Translations can be filed in the /languages/ directory
	load_theme_textdomain( 'jeans', TEMPLATEPATH . '/languages' );
	
	register_nav_menus( array(
		'primary' => __( 'Primary Navigation', 'jeans' ),
		) );
	
	// This theme allows users to set a custom background
	add_custom_background();
	
	define( 'HEADER_TEXTCOLOR', 'FFF' );
	define( 'HEADER_IMAGE', '' );

	// The height and width of your custom header. You can hook into the theme's own filters to change these values.
	// Add a filter to jeans_header_image_width and jeans_header_image_height to change these values.
	define( 'HEADER_IMAGE_WIDTH', apply_filters( 'jeans_header_image_width', 960 ) );
	define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'jeans_header_image_height', 302 ) );

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be 940 pixels wide by 198 pixels tall.
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true );

	// Add Twenty Eleven's custom image sizes
	add_image_size( 'large-feature', HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true ); // Used for large feature (header) images
	add_image_size( 'small-feature', 500, 300 ); // Used for featured posts if a large-feature doesn't exist

	// Turn on random header image rotation by default.
	add_theme_support( 'custom-header', array( 'random-default' => true ) );

	// Add a way for the custom header to be styled in the admin panel that controls
	// custom headers. See jeans_admin_header_style(), below.
	add_custom_image_header( 'jeans_header_style', 'jeans_admin_header_style', 'jeans_admin_header_image' );

	// ... and thus ends the changeable header business.

	// Default custom headers packaged with the theme. %s is a placeholder for the theme template directory URI.
	register_default_headers( array(
		'cowboy' => array(
			'url' => '%s/images/headers/cowboy.jpg',
			'thumbnail_url' => '%s/images/headers/cowboy-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'cowboy', 'jeans' )
		),
		'grasslands' => array(
			'url' => '%s/images/headers/grasslands.jpg',
			'thumbnail_url' => '%s/images/headers/grasslands-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'grasslands', 'jeans' )
		),
		'dusk' => array(
			'url' => '%s/images/headers/dusk.jpg',
			'thumbnail_url' => '%s/images/headers/dusk-thumbnail.jpg',
			/* translators: header image description */
			'description' => __( 'dusk', 'jeans' )
		)
	) );
}


if ( ! function_exists( 'jeans_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 */
function jeans_header_style() {

	// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
	if ( HEADER_TEXTCOLOR == get_header_textcolor() )
		return;
	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == get_header_textcolor() ) :
	?>
		#site-title,
		#site-description {
			position: absolute !important;
			clip: rect(1px 1px 1px 1px); /* IE6, IE7 */
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		#site-title a,
		#site-description {
			color: #<?php echo get_header_textcolor(); ?> !important;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // jeans_header_style

if ( ! function_exists( 'jeans_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 */
function jeans_admin_header_style() {
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		border: none;
	}
	#headimg h1,
	#desc {
		font-family: "Helvetica Neue", Arial, Helvetica, "Nimbus Sans L", sans-serif;
	}
	#headimg h1 {
		margin: 0;
	}
	#headimg h1 a {
		font-size: 32px;
		line-height: 36px;
		text-decoration: none;
	}
	#desc {
		font-size: 14px;
		line-height: 23px;
		padding: 0 0 3em;
	}
	<?php
		// If the user has set a custom color for the text use that
		if ( get_header_textcolor() != HEADER_TEXTCOLOR ) :
	?>
		#site-title a,
		#site-description {
			color: #<?php echo get_header_textcolor(); ?>;
		}
	<?php endif; ?>
	#headimg img {
		max-width: 960px;
		height: auto;
		width: 100%;
	}
	</style>
<?php
}
endif; // jeans_admin_header_style

if ( ! function_exists( 'jeans_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 */
function jeans_admin_header_image() { ?>
	<div id="headimg">
		<?php
		if ( 'blank' == get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) || '' == get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) )
			$style = ' style="display:none;"';
		else
			$style = ' style="color:#' . get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) . ';"';
		?>
		<h1><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" alt="" />
		<?php endif; ?>
	</div>
<?php }
endif; // jeans_admin_header_image

add_action( 'after_setup_theme', 'jeans_setup'); 

function jeans_the_thumbnail() {   
 
global $post;   

if ( has_post_thumbnail() ) {   
echo '<a href="'.get_permalink().'" title="Read More">';   
the_post_thumbnail('thumbnail');   
echo '</a>';   
} else {   

$content = $post->post_content;   
preg_match_all('/<img.*?(?: |\\t|\\r|\\n)?src=[\'"]?(.+?)[\'"]?(?:(?: |\\t|\\r|\\n)+.*?)?>/sim', $content, $strResult, PREG_PATTERN_ORDER);   
$n = count($strResult[1]);  
 
if($n > 0){    
            echo '<a href="'.get_permalink().'" title="Read More"><img src="'.$strResult[1][0].'" alt="thumbnail" /></a>';   
        }else {      
            echo '<a href="'.get_permalink().'" title="Read More"><img src="'.get_bloginfo('template_url').'/images/thumbnail.png" alt="thumbnail" /></a>';  
       }   
  }    
}  

function jeans_new_excerpt_length($length) {
return 80;
}
add_filter('excerpt_length', 'jeans_new_excerpt_length',999);


add_filter( 'use_default_gallery_style', '__return_false' );

function jeans_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}
// Backwards compatibility with WordPress 3.0.
if ( version_compare( $GLOBALS['wp_version'], '3.1', '<' ) )
	add_filter( 'gallery_style', 'jeans_remove_gallery_css' );
	



if ( ! function_exists( 'jeans_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function jeans_posted_on() {
	printf( __( '<span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a><span class="by-author"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'jeans' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		sprintf( esc_attr__( 'View all posts by %s', 'jeans' ), get_the_author() ),
		esc_html( get_the_author() )
	);
}
endif;
      

function jeans_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'jeans_page_menu_args' );

?>